#!/bin/csh
#
#   Command file to run prime-and-switch phasing on "sigmaa_2EIF.mtz" and
#   write out "ps_2EIF.mtz"
#
#   The data in sigmaa_2EIF.mtz are from PDB entry 2EIF 
#   (M. jannaschii IF5A) rotated and translated to best
#   match the P. aerophilum IF5A (PDB entry 1BKB), 
#   in the file 2EIF_SUPERIMPOSED.PDB,
#   using measured amplitudes of
#   structure factors corresponding to P. aerophilum
#   IF5A 
#
#   For P. aerophilum IF5A, see Peat et 
#   al., Structure 6, 1207-1214 (1998). The refined
#   structure of IF5A is in the PDB file "1BKB.pdb" 
#   included in this directory.
#
#   All resolve needs to run is the solvent content
#   if it is reading SOLVE output.
#
#   Note: see http://solve.lanl.gov for more
#   information on keywords you can use.
#
#   tell resolve the location of "symop.lib" and also
#   tell resolve to overwrite files:
#
setenv SYMOP /usr/local/lib/resolve/symop.lib
setenv CCP4_OPEN UNKNOWN
#
#   ready to run resolve:
#
resolve << EOD
hklin sigmaa_2EIF.mtz
labin FP=FP FC=FC PHIC=PHIC FOM=WCMB
mask_cycles 10
minor_cycles 10
solvent_content 0.60        !    solvent fraction
prime_and_switch
hklout resolve_ps.mtz
EOD
#
#  All done, now resolve_ps.mtz has modified phases that should match
#  p9.pdb, not 2EIF_SUPERIMPOSED.PDB
